==> haskell-hls-ormolu-plugin-1.0.4.0-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-ormolu-plugin
version:              1.0.4.0
visibility:           public
id:                   hls-ormolu-plugin-1.0.4.0-1ZJ1CKKeUPlIEzTJSLgTZq
key:                  hls-ormolu-plugin-1.0.4.0-1ZJ1CKKeUPlIEzTJSLgTZq
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3448909c9eaeb132e0c25583518b2fa5
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-ormolu-plugin-1.0.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-ormolu-plugin-1.0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-1.0.4.0-1ZJ1CKKeUPlIEzTJSLgTZq
depends:
    base-4.16.4.0 filepath-1.4.2.2 ghc-9.2.8 ghc-boot-th-9.2.8
    ghcide-1.10.0.0-HHQ8G8WsjSJ2AEMQGOwX6
    hls-plugin-api-1.6.0.0-J7scbURco0w3rSkQkePbC4
    lens-5.2.3-Ip76jddesOj5vmVbK7jYXC
    lsp-1.6.0.0-2t8x0RCtMfUJVfdZdVq4q7
    ormolu-0.5.0.1-KfDX5PLgjxaFdZpov2kOOC text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-ormolu-plugin-1.0.4.0-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-ormolu-plugin
version:              1.0.4.0
visibility:           public
id:                   hls-ormolu-plugin-1.0.4.0-6n3w0rpUcJ69yBweqHkRqp
key:                  hls-ormolu-plugin-1.0.4.0-6n3w0rpUcJ69yBweqHkRqp
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4b49e06765bbc389448544aaa1c463d1
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-ormolu-plugin-1.0.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-ormolu-plugin-1.0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-1.0.4.0-6n3w0rpUcJ69yBweqHkRqp
depends:
    base-4.16.4.0 filepath-1.4.2.2 ghc-9.2.8 ghc-boot-th-9.2.8
    ghcide-1.10.0.0-IK0p0knsZKJ6ifDWycSJqV
    hls-plugin-api-1.6.0.0-AWK1aZFAUysD3mmtii36PC
    lens-5.2.3-Ip76jddesOj5vmVbK7jYXC
    lsp-1.6.0.0-2t8x0RCtMfUJVfdZdVq4q7
    ormolu-0.5.0.1-KfDX5PLgjxaFdZpov2kOOC text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
